@@ -84,6 +84,9 @@ typedef struct
         void (* disconnected)                (GdmSession   *session);
         void (* verification_complete)       (GdmSession   *session,
                                               const char   *service_name);
+        void (* authentication_failed)       (GdmSession   *session,
+                                              const char   *service_name,
+                                              GPid          worker_pid);
         void (* session_opened)              (GdmSession   *session,
                                               const char   *service_name,
                                               const char   *session_id);
@@ -134,10 +137,12 @@ const char       *gdm_session_get_session_id              (GdmSession     *sessi
 gboolean          gdm_session_bypasses_xsession           (GdmSession     *session);
 GdmSessionDisplayMode gdm_session_get_display_mode  (GdmSession     *session);
 
-void              gdm_session_start_conversation          (GdmSession *session,
+gboolean          gdm_session_start_conversation          (GdmSession *session,
                                                            const char *service_name);
 void              gdm_session_stop_conversation           (GdmSession *session,
                                                            const char *service_name);
+const char       *gdm_session_get_conversation_session_id (GdmSession *session,
+                                                           const char *service_name);
 void              gdm_session_setup                       (GdmSession *session,
                                                            const char *service_name);
 void              gdm_session_setup_for_user              (GdmSession *session,
@@ -182,6 +187,7 @@ void              gdm_session_set_timed_login_details     (GdmSession *session,
                                                            int         delay);
 gboolean          gdm_session_client_is_connected         (GdmSession *session);
 gboolean          gdm_session_is_running                  (GdmSession *session);
+GPid              gdm_session_get_pid                     (GdmSession *session);
 
 G_END_DECLS
 
